@@ -413,7 +413,8 @@ class VariableClDesktopUpdateProfileSet(Variable):
         profileSetup = userIni.getVar('main', 'profile_setup')
         login_setup = profileSetup == 'on'
 
-        if (self.Get('ur_domain_set') == 'on' or not is_fastlogin or login_setup or
+        if (self.Get('ur_domain_set') == 'on' or
+                not self.is_fastlogin() or login_setup or
                 not path.exists(iniEnv) or userTimestamp != lastTimestamp):
             return 'on'
         else:
